MemoryStorage

Struct MemoryStorage 

pub struct MemoryStorage { /* private fields */ }
In-memory CRDT storage for testing.

This implementation stores all data in memory using HashMap and Vec. It’s thread-safe via RwLock but data is lost when dropped.

Auto-compaction is triggered when the number of updates for a document exceeds [AUTO_COMPACT_THRESHOLD], keeping the most recent [AUTO_COMPACT_KEEP] updates.

Implementations

Source

impl MemoryStorage

pub fn new() -> Self

Create a new empty in-memory storage.