pub struct MemoryStorage { /* private fields */ }Expand description
In-memory CRDT storage for testing.
This implementation stores all data in memory using HashMap and Vec.
It’s thread-safe via RwLock but data is lost when dropped.
Auto-compaction is triggered when the number of updates for a document
exceeds [AUTO_COMPACT_THRESHOLD], keeping the most recent
[AUTO_COMPACT_KEEP] updates.
Implementations
Sourceimpl MemoryStorage
impl MemoryStorage